@@ -65,12 +65,18 @@ class KeystokClient:
 
     def get_key(self, key_id):
         url = '%s/apps/%s/deploy/%s?access_token=%s' % (self.options['api_host'], self.token['id'], key_id, self.refresh_access_token(self.token))
-        response = requests.get(url).json()
+        r = requests.get(url)
+        if r.status_code != 200:
+            raise Exception('Error retrieving key from server: ' + str(r.status_code))
+        response = r.json()
         return self.decrypt_data(self.token, response[key_id]['key'])
 
     def list_keys(self):
         url = '%s/apps/%s/keys?access_token=%s' % (self.options['api_host'], self.token['id'], self.refresh_access_token(self.token))
-        response = requests.get(url).json()
+        r = requests.get(url)
+        if r.status_code != 200:
+            raise Exception('Error retrieving keys from server: ' + str(r.status_code))
+        response = r.json()
         return response
 
     def cmd_ls(self):
@@ -150,11 +156,18 @@ class KeystokClient:
             pass
 
         # Must refresh to get new access token
-        data = urlencode({
+        data = {
             'grant_type': 'refresh_token',
             'refresh_token': refresh_token,
-        })
-        response = requests.post(self.options['auth_host'], data).json()
+        }
+        r = requests.post(self.options['auth_host'], data)
+        if r.status_code != 200:
+            # Failed to refresh
+            raise Exception('Error refreshing OAuth access token: ' + str(r.status_code))
+        response = r.json()
+        if not ('expires_in' in response and 'access_token' in response):
+            # Invalid response
+            raise Exception('Invalid OAuth access token refresh response')
         response['expires_at'] = int(time.time()) + response['expires_in']
 
         with open(os.path.join(self.cache_path, 'access_token'), 'w') as f:
